@@ -350,11 +350,11 @@ class IWidget(IWidgetInterface, ABC):
         if text is None:
             return
 
-        text = self._font.render(text, 1, color, bg_color)
-        textpos = text.get_rect()
+        text_bmp = self._font.render(text, 1, color, bg_color)
+        textpos = text_bmp.get_rect()
         textpos.centerx = self._x + (self._w / 2)
         textpos.centery = self._y + (self._h / 2)
-        surface.blit(text, textpos)
+        surface.blit(text_bmp, textpos)
 
     def render_left_text(self, surface, text, color, bg_color=None):
         """ Render text in the left side of the widget.
@@ -371,11 +371,11 @@ class IWidget(IWidgetInterface, ABC):
         if text is None:
             return
 
-        text = self._font.render(text, 1, color, bg_color)
-        textpos = text.get_rect()
+        text_bmp = self._font.render(text, 1, color, bg_color)
+        textpos = text_bmp.get_rect()
         textpos.left = self._x
         textpos.centery = self._y + (self._h / 2)
-        surface.blit(text, textpos)
+        surface.blit(text_bmp, textpos)
 
     def render_right_text(self, surface, text, color, bg_color=None):
         """ Render text in the right side of the widget.
@@ -392,11 +392,11 @@ class IWidget(IWidgetInterface, ABC):
         if text is None:
             return
 
-        text = self._font.render(text, 1, color, bg_color)
-        textpos = text.get_rect()
+        text_bmp = self._font.render(text, 1, color, bg_color)
+        textpos = text_bmp.get_rect()
         textpos.right = self._x + self._w - 1
         textpos.centery = self._y + (self._h / 2)
-        surface.blit(text, textpos)
+        surface.blit(text_bmp, textpos)
 
     def render_focus(self, surface):
         """ Render a default focus outline.
