@@ -139,10 +139,10 @@ class GUI(object):
 
             new_page = self._current_page.touch_handler(e, t)
             if new_page is not None:
-                if isinstance(new_page, Page):
-                    self._current_page = new_page
-                else:
-                    LOG.error(f"Unsupported touch result {type(new_page)!r}")
+                # if isinstance(new_page, Page):
+                self._current_page = new_page
+                # else:
+                #     LOG.error(f"Unsupported touch result {type(new_page)!r}")
 
         # All touch types go through the `Page.touch_handler()`
         for touch in self._touchscreen.touches:
