@@ -62,11 +62,8 @@ class Page(object):
             background = str(Path(Path(__file__).parent,
                                        "assets/lcars_screen.png"))
         self.background = background
+        self._bg_image = None
 
-        if background is not None:
-            self._bg_image = pygame.image.load(background).convert()
-        else:
-            self._bg_image = None
         self.function = function
 
         self._focus_widget = None
@@ -247,6 +244,10 @@ class Page(object):
         surface : pygame.Surface
             Surface (screen) to draw to
         """
+        # Lazy loading to avoid pygame initialization issues
+        if self._bg_image is None and self.background is not None:
+            self._bg_image = pygame.image.load(self.background).convert()
+
         if self._bg_image is not None:
             surface.blit(self._bg_image, (0, 0))
         else:
