@@ -13,6 +13,13 @@ from tests._utilities import pulsing_light_func
 from widget_buttons import Button
 from widget_displays import Light, Label
 
+_left_label = Label((20, 50), (100, 50),
+                    label="L",label_alignment=Label.LEFT)
+_center_label = Label((20, 100), (100, 50),
+                    label="C",label_alignment=Label.CENTER)
+_right_label = Label((20, 150), (100, 50),
+                    label="R",label_alignment=Label.RIGHT)
+
 _entry_label = Label((0, 0), (800, 50), label="ENTER")
 
 _pulse1_light = Light((0, 0), (50, 50), function=pulsing_light_func)
@@ -41,6 +48,9 @@ def entry_page():
     # Tests dynamic Light functions, Label, and default Page function
     _entry_page = Page('entry', [
         _entry_label,
+        _left_label,
+        _center_label,
+        _right_label,
         _pulse1_light,
         _pulse2_light,
         _pulse3_light,
